@@ -21,6 +21,32 @@
 #'   
 NULL
 
+#' @describeIn FitDynamicGrowthMCMC print of the model
+#' 
+#' @param x An instance of \code{FitDynamicGrowthMCMC}.
+#' @param ... ignored
+#' 
+#' @export
+#' 
+print.FitDynamicGrowthMCMC <- function(x, ...) {
+    
+    cat("Growth model fitted to dynamic condictions using MCMC\n\n")
+    
+    env <- names(x$env_conditions)
+    cat(paste("Environmental factors included:", paste(env, collapse = ", "), "\n\n"))
+    
+    cat("Parameters of the primary model:\n")
+    print(unlist(x$best_prediction$primary_pars))
+    cat("\n")
+    
+    for (i in 1:length(x$best_prediction$sec_models)) {
+        cat(paste("Secondary model for ", names(x$best_prediction$sec_models)[i], ":\n", sep = ""))
+        print(unlist(x$best_prediction$sec_models[[i]]))
+        cat("\n")
+    }
+    
+}
+
 #' @describeIn FitDynamicGrowthMCMC compares the model fitted against the data.
 #'
 #' @param x The object of class \code{FitDynamicGrowthMCMC} to plot.
